Ligature is a Python library that builds up ways of stitching data together.

It builds from low to high level abstractions, demonstrating how they work together.

The goal is to make data composable, but also to make sure it's clear exactly what is being done at any given stage.